@@ -32,7 +32,7 @@
 ** in libc to "_" + the old name (Ie, "getpwnam" -> "_getpwnam")
 ** if you do this.
 */
-/* #define FINALOUT */
+#define FINALOUT 1
 
 
 /*
@@ -59,10 +59,5 @@
 */
 /* #define HAVE_BUGGY_YP_X 1 */
 
-/*
-** Linux machines with libc 4.4.4 (and probably before and after) have
-** a buggy inet_network() function.
-*/
-#define HAVE_BUGGY_INET_NETWORK 1
 
 #endif
