@@ -34,14 +34,35 @@ extern nis_result *nis_first_entry(nis_name name);
 extern nis_result *nis_next_entry(nis_name name, netobj *key);
 extern void nis_freeresult(nis_result *res);
 
+extern nis_name nis_local_directory(void);
+extern nis_name nis_local_host(void);
+extern nis_name nis_local_group(void);
+extern nis_name nis_local_principal(void);
+extern nis_name *nis_getnames(const nis_name name);
+
+extern const char *nis_sperrno(const nis_error status);
+extern void nis_perror(const nis_error status, const char *label);
+extern void nis_lerror(const nis_error status, const char *label);
+extern char *nis_sperror(const nis_error status, const char *label);
+
+
+/*
+** Defines for the nis_lookup() and nis_list()
+*/
+#define FOLLOW_LINKS     0x01
+#define FOLLOW_PATH      0x02
+#define HARD_LOOKUP      0x04
+#define ALL_RESULTS      0x08
+#define NO_CACHE         0x10
+#define MASTER_ONLY      0x20
+#define EXPAND_NAME      0x40
 
 /*
 ** NYS-specific NIS+ client functions, you should
 ** probably not use these in your programs if you care
 ** at all for portability
 */
-extern int nis_get_default_domain(char **outdomain);
-extern nis_name nis_mkfullname(nis_name name, char **outdomain);
+extern int nis_setup(void);
 
 #endif
 
