@@ -29,7 +29,7 @@
 #include "nis_print.h"
 
 
-void _nis_print_directory(directory_obj *dob, int ind, FILE *fp)
+void nis_fprint_directory(directory_obj *dob, int ind, FILE *fp)
 {
     fprintf(fp, "%*sName = %s\n", ind, "", dob->do_name);
     fprintf(fp, "%*sType = %d\n", ind, "", dob->do_type);
@@ -38,11 +38,11 @@ void _nis_print_directory(directory_obj *dob, int ind, FILE *fp)
 
 void nis_print_directory(directory_obj *dob)
 {
-    _nis_print_directory(dob, 0, stdout);
+    nis_fprint_directory(dob, 0, stdout);
 }
 
 
-void _nis_print_group(group_obj *go, int ind, FILE *fp)
+void nis_fprint_group(group_obj *go, int ind, FILE *fp)
 {
     int i;
     
@@ -56,11 +56,11 @@ void _nis_print_group(group_obj *go, int ind, FILE *fp)
 
 void nis_print_group(group_obj *go)
 {
-    _nis_print_group(go, 0, stdout);
+    nis_fprint_group(go, 0, stdout);
 }
 
 
-void _nis_print_table_col(table_col *tc, int ind, FILE *fp)
+void nis_fprint_table_col(table_col *tc, int ind, FILE *fp)
 {
    fprintf(fp, "%*sName   = %s\n", ind, "", tc->tc_name);
    fprintf(fp, "%*sFlags  = 0x%08lX (%s)\n", ind, "", tc->tc_flags,
@@ -70,7 +70,7 @@ void _nis_print_table_col(table_col *tc, int ind, FILE *fp)
 }
 
 
-void _nis_print_table(table_obj *to, int ind, FILE *fp)
+void nis_fprint_table(table_obj *to, int ind, FILE *fp)
 {
     int i;
     
@@ -81,7 +81,7 @@ void _nis_print_table(table_obj *to, int ind, FILE *fp)
     for (i = 0; i < to->ta_cols.ta_cols_len; i++)
     {
 	fprintf(fp, "%*s  Column #%d:\n", ind, "", i);
-	_nis_print_table_col(&to->ta_cols.ta_cols_val[i], ind+4, fp);
+	nis_fprint_table_col(&to->ta_cols.ta_cols_val[i], ind+4, fp);
     }
 
     fprintf(fp, "%*sPath = %s\n", ind, "", to->ta_path);
@@ -89,11 +89,11 @@ void _nis_print_table(table_obj *to, int ind, FILE *fp)
 
 void nis_print_table(table_obj *to)
 {
-    _nis_print_table(to, 0, stdout);
+    nis_fprint_table(to, 0, stdout);
 }
 
 
-void _nis_print_entry_col(entry_col *ec, int ind, FILE *fp)
+void nis_fprint_entry_col(entry_col *ec, int ind, FILE *fp)
 {
     fprintf(fp, "%*sFlags = %08lX (%s)\n", ind, "", ec->ec_flags,
 	   nis_enflags2str(ec->ec_flags, NULL));
@@ -102,7 +102,7 @@ void _nis_print_entry_col(entry_col *ec, int ind, FILE *fp)
 }
 
 
-void _nis_print_entry(entry_obj *eo, int ind, FILE *fp)
+void nis_fprint_entry(entry_obj *eo, int ind, FILE *fp)
 {
     int i;
     
@@ -111,17 +111,17 @@ void _nis_print_entry(entry_obj *eo, int ind, FILE *fp)
     for (i = 0; i < eo->en_cols.en_cols_len; i++)
     {
 	fprintf(fp, "%*s  Value #%d:\n", ind, "", i);
-	_nis_print_entry_col(&eo->en_cols.en_cols_val[i], ind+4, fp);
+	nis_fprint_entry_col(&eo->en_cols.en_cols_val[i], ind+4, fp);
     }
 }
 
 void nis_print_entry(entry_obj *eo)
 {
-    _nis_print_entry(eo, 0, stdout);
+    nis_fprint_entry(eo, 0, stdout);
 }
 
 
-void _nis_print_attr(nis_attr *at, int ind, FILE *fp)
+void nis_fprint_attr(nis_attr *at, int ind, FILE *fp)
 {
     fprintf(fp, "%*sNDX = %s\n", ind, "", at->zattr_ndx);
     fprintf(fp, "%*sLength = %d\n", ind, "", at->zattr_val.zattr_val_len);
@@ -129,11 +129,11 @@ void _nis_print_attr(nis_attr *at, int ind, FILE *fp)
 
 void nis_print_attr(nis_attr *at)
 {
-    _nis_print_attr(at, 0, stdout);
+    nis_fprint_attr(at, 0, stdout);
 }
 
 
-void _nis_print_link(link_obj *lo, int ind, FILE *fp)
+void nis_fprint_link(link_obj *lo, int ind, FILE *fp)
 {
     int i;
     
@@ -143,17 +143,17 @@ void _nis_print_link(link_obj *lo, int ind, FILE *fp)
     for (i = 0; i < lo->li_attrs.li_attrs_len; i++)
     {
 	fprintf(fp, "%*s  Attribute #%d:\n", ind, "", i);
-	_nis_print_attr(&lo->li_attrs.li_attrs_val[i], ind+4, fp);
+	nis_fprint_attr(&lo->li_attrs.li_attrs_val[i], ind+4, fp);
     }
 }
 
 void nis_print_link(link_obj *lo)
 {
-    _nis_print_link(lo, 0, stdout);
+    nis_fprint_link(lo, 0, stdout);
 }
 
 
-void _nis_print_objdata(objdata *obd, int ind, FILE *fp)
+void nis_fprint_objdata(objdata *obd, int ind, FILE *fp)
 {
     fprintf(fp, "%*sObjType = %d ", ind, "", obd->zo_type);
     switch (obd->zo_type)
@@ -168,27 +168,27 @@ void _nis_print_objdata(objdata *obd, int ind, FILE *fp)
 	
       case DIRECTORY_OBJ:
 	fprintf(fp, "(Directory)\n");
-	_nis_print_directory(&obd->objdata_u.di_data, ind+4, fp);
+	nis_fprint_directory(&obd->objdata_u.di_data, ind+4, fp);
 	break;
 
       case GROUP_OBJ:
 	fprintf(fp, "(Group)\n");
-	_nis_print_group(&obd->objdata_u.gr_data, ind+4, fp);
+	nis_fprint_group(&obd->objdata_u.gr_data, ind+4, fp);
 	break;
 
       case TABLE_OBJ:
 	fprintf(fp, "(Table)\n");
-	_nis_print_table(&obd->objdata_u.ta_data, ind+4, fp);
+	nis_fprint_table(&obd->objdata_u.ta_data, ind+4, fp);
 	break;
 
       case ENTRY_OBJ:
 	fprintf(fp, "(Entry)\n");
-	_nis_print_entry(&obd->objdata_u.en_data, ind+4, fp);
+	nis_fprint_entry(&obd->objdata_u.en_data, ind+4, fp);
 	break;
 
       case LINK_OBJ:
 	fprintf(fp, "(Link)\n");
-	_nis_print_link(&obd->objdata_u.li_data, ind+4, fp);
+	nis_fprint_link(&obd->objdata_u.li_data, ind+4, fp);
 	break;
 
       case PRIVATE_OBJ:
@@ -204,7 +204,7 @@ void _nis_print_objdata(objdata *obd, int ind, FILE *fp)
 }
 
 
-void _nis_print_object(nis_object *ob, int ind, FILE *fp)
+void nis_fprint_object(nis_object *ob, int ind, FILE *fp)
 {
     fprintf(fp, "%*sObject created at %s", ind, "", ctime(&ob->zo_oid.ctime));
     fprintf(fp, "%*s last modified at %s", ind, "", ctime(&ob->zo_oid.mtime));
@@ -216,16 +216,16 @@ void _nis_print_object(nis_object *ob, int ind, FILE *fp)
 	   nis_access2str(ob->zo_access, NULL));
     fprintf(fp, "%*sTTL    = %lu (seconds)\n", ind, "", ob->zo_ttl);
     
-    _nis_print_objdata(&ob->zo_data, ind+4, fp);
+    nis_fprint_objdata(&ob->zo_data, ind+4, fp);
 }
 
 void nis_print_object(nis_object *ob)
 {
-    _nis_print_object(ob, 0, stdout);
+    nis_fprint_object(ob, 0, stdout);
 }
 
 
-void _nis_print_result(nis_result *nsres, int ind, FILE *fp)
+void nis_fprint_result(nis_result *nsres, int ind, FILE *fp)
 {
     int i;
 
@@ -237,11 +237,11 @@ void _nis_print_result(nis_result *nsres, int ind, FILE *fp)
     for (i = 0; i < nsres->objects.objects_len; i++)
     {
 	fprintf(fp, "%*s  Object #%d:\n", ind, "", i);
-	_nis_print_object(&nsres->objects.objects_val[i], ind+4, fp);
+	nis_fprint_object(&nsres->objects.objects_val[i], ind+4, fp);
     }
 }
 
 void nis_print_result(nis_result *res)
 {
-    _nis_print_result(res, 0, stdout);
+    nis_fprint_result(res, 0, stdout);
 }
