@@ -27,10 +27,10 @@
 #include <sys/types.h>
 #include <ethers.h>
 
-void dns_setethent(void *opts);
-void dns_endethent(void *opts);
-struct ether * dns_getethent(void *opts);
-struct ether * dns_getethbyname(char *name, void *opts);
-struct ether * dns_getethbyaddr(struct ether_addr *addr, void *opts);
+extern void dns_setethent(void);
+extern void dns_endethent(void);
+extern struct ether * dns_getethent(void);
+extern struct ether * dns_getethbyname(const char *name);
+extern struct ether * dns_getethbyaddr(const struct ether_addr *addr);
 
 #endif
