@@ -30,31 +30,31 @@
 #include "dns_networks.h"
 
 
-void dns_setnetent(int stayopen, void *opts)
+void dns_setnetent(int stayopen)
 {
 }
 
 
-void dns_endnetent(void *opts)
+void dns_endnetent(void)
 {
 }
 
 
-struct netent *dns_getnetent(void *opts)
+struct netent *dns_getnetent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct netent *dns_getnetbyname(const char *name, void *opts)
+struct netent *dns_getnetbyname(const char *name)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct netent *dns_getnetbyaddr(long net, int type, void *opts)
+struct netent *dns_getnetbyaddr(long net, int type)
 {
     errno = ECONNREFUSED;
     return NULL;
