@@ -29,13 +29,11 @@
 #include <sys/types.h>
 #include <netdb.h>
 
-extern void dns_setprotoent(int stayopen, void *opts);
-extern void dns_endprotoent(void *opts);
-extern struct protoent *dns_getprotoent(void *opts);
-extern struct protoent *dns_getprotobyname(const char *name,
-					   void *opts);
-extern struct protoent *dns_getprotobynumber(int number,
-					     void *opts);
+extern void dns_setprotoent(int stayopen);
+extern void dns_endprotoent(void);
+extern struct protoent *dns_getprotoent(void);
+extern struct protoent *dns_getprotobyname(const char *name);
+extern struct protoent *dns_getprotobynumber(int number);
 
 #endif
 
