@@ -33,24 +33,24 @@
 #include "dns_shadow.h"
 
 
-void dns_setspent(void *opts)
+void dns_setspent(void)
 {
 }
 
 
-void dns_endspent(void *opts)
+void dns_endspent(void)
 {
 }
 
 
-struct spwd *dns_getspent(void *opts)
+struct spwd *dns_getspent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct spwd *dns_getspnam(const char *name, void *opts)
+struct spwd *dns_getspnam(const char *name)
 {
     errno = ECONNREFUSED;
     return NULL;
