@@ -29,11 +29,11 @@
 #include <pwd.h>
 #include <sys/types.h>
 
-extern void nis_setpwent(void *opts);
-extern void nis_endpwent(void *opts);
-extern struct passwd *nis_getpwent(void *opts);
-extern struct passwd *nis_getpwuid(uid_t uid, void *opts);
-extern struct passwd *nis_getpwnam(const char *name, void *opts);
+extern void nis_setpwent(void);
+extern void nis_endpwent(void);
+extern struct passwd *nis_getpwent(void);
+extern struct passwd *nis_getpwuid(uid_t uid);
+extern struct passwd *nis_getpwnam(const char *name);
 
 #endif
 
