@@ -30,32 +30,31 @@
 #include "nis_protocols.h"
 
 
-void nis_setprotoent(int stayopen, void *opts)
+void nis_setprotoent(int stayopen)
 {
 }
 
 
-void nis_endprotoent(void *opts)
+void nis_endprotoent(void)
 {
 }
 
 
-struct protoent *nis_getprotoent(void *opts)
+struct protoent *nis_getprotoent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct protoent *nis_getprotobyname(const char *name,
-				    void *opts)
+struct protoent *nis_getprotobyname(const char *name)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct protoent *nis_getprotobynumber(int number, void *opts)
+struct protoent *nis_getprotobynumber(int number)
 {
     errno = ECONNREFUSED;
     return NULL;
