@@ -42,7 +42,7 @@
 void _ENSWF(_setprotoent)(int stayopen);
 void _ENSWF(_endprotoent)(void);
 struct protoent * _ENSWF(_getprotoent)(void);
-struct protoent * _ENSWF(_getprotobyname)(char *name);
+struct protoent * _ENSWF(_getprotobyname)(const char *name);
 struct protoent * _ENSWF(_getprotobynumber)(int number);
 
 #endif
