@@ -44,6 +44,6 @@
 void _ENSWF(_setspent)(void);
 void _ENSWF(_endspent)(void);
 struct spwd * _ENSWF(_getspent)(void);
-struct spwd * _ENSWF(_getspnam)(char *name);
+struct spwd * _ENSWF(_getspnam)(const char *name);
 
 #endif
