@@ -34,7 +34,7 @@ main(int argc, char *argv[])
     struct hostent *host;
 
 
-    host = dns_gethostbyname(argv[1], NULL);
+    host = dns_gethostbyname(argv[1]);
 
     if (host)
 	print_hosts(host);
@@ -45,10 +45,3 @@ main(int argc, char *argv[])
 }
 
 
-
-
-
-
-
-
-
