@@ -40,12 +40,12 @@ main(int argc, char *argv[])
 {
    struct hostent *host;
    unsigned long test;
-   extern struct hostent *_gethostbyaddr();
+
    
    if (argc >= 2)
       test = inet_addr(argv[1]);
 
-   host = _gethostbyaddr((char *) &test, sizeof(unsigned long),
+   host = gethostbyaddr((char *) &test, sizeof(unsigned long),
 			   AF_INET);
 
     if (host)
