@@ -33,12 +33,12 @@ int main(int argc, char *argv[])
     struct passwd *pw;
 
 
-    yp_setpwent(NULL);
+    yp_setpwent();
 
-    while ((pw = yp_getpwent(NULL)) != NULL)
+    while ((pw = yp_getpwent()) != NULL)
 	print_passwd(pw);
 
-    yp_endpwent(NULL);
+    yp_endpwent();
     
     exit(0);
 }
