@@ -34,7 +34,7 @@ int main(int argc, char *argv[])
     struct passwd *pw;
 
 
-    pw = yp_getpwuid(atoi(argv[1]), NULL);
+    pw = yp_getpwuid(atoi(argv[1]));
 
     if (pw)
 	print_passwd(pw);
